@@ -27,10 +27,11 @@ class AES(object):
 		self.block_size = 16
 		self.pad = lambda s: s + (self.block_size - len(s) % self.block_size) * chr(self.block_size - len(s) % self.block_size)
 		self.unpad = lambda s: s[:-ord(s[len(s) - 1:])]
-		
+		#
 	def encrypt(self, raw):
 		if raw in ["", b"", None, False]:
 			return r3sponse.error("Can not encrypt null data.")
+		raw = Formats.denitialize(raw)
 		response = self.get_key()
 		if not response.success: return response
 		key = response["key"]
@@ -49,6 +50,7 @@ class AES(object):
 	def decrypt(self, enc):
 		if enc in ["", b"", None, False]:
 			return r3sponse.error("Can not decrypt null data.")
+		enc = Formats.denitialize(enc)
 		if isinstance(enc, str):
 			enc = enc.encode()
 		enc = base64.b64decode(enc)
@@ -108,6 +110,7 @@ class AsymmetricAES(object):
 	def load_public_key(self):
 		return self.rsa.load_public_key()
 	def encrypt(self, string, decode=False):
+		string = Formats.denitialize(string)
 		if isinstance(string, bytes):
 			string = string.decode()
 		
@@ -138,6 +141,7 @@ class AsymmetricAES(object):
 	def decrypt(self, string, decode=False):
 
 		# split encrypted aes key.
+		string = Formats.denitialize(string)
 		if isinstance(string, bytes):
 			string = string.decode()
 		try:
@@ -165,7 +169,8 @@ class AsymmetricAES(object):
 
 		#
 	def encrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
-		
+		input = Formats.denitialize(input)
+		ouput = Formats.denitialize(ouput)
 
 		# check params.
 		response = r3sponse.check_parameters({
@@ -194,7 +199,8 @@ class AsymmetricAES(object):
 
 		#
 	def decrypt_file(self, input=None, output=None, remove=False, base64_encoding=False):
-		
+		input = Formats.denitialize(input)
+		ouput = Formats.denitialize(ouput)
 
 		# check params.
 		response = r3sponse.check_parameters({
@@ -223,9 +229,11 @@ class AsymmetricAES(object):
 
 		#
 	def encrypt_directory(self, input=None, output=None, remove=False):
+		input = Formats.denitialize(input)
+		ouput = Formats.denitialize(ouput)
 
 		# checks.
-		file_path = Formats.FilePath(input)
+		file_path = FilePath(input)
 		if not file_path.exists():
 			return r3sponse.error(f"Directory [{input}] does not exist.")
 		if not file_path.directory():
@@ -242,20 +250,20 @@ class AsymmetricAES(object):
 			zip_path = output
 
 		# check output.
-		if os.path.exists(zip_path):
+		if Files.exists(zip_path):
 			return r3sponse.error(f"output path [{zip_path}] already exists.")
 
 		# create zip.
-		zip = Files.Zip(path=zip_path)
+		zip = Zip(path=zip_path)
 		zip.create(source=input)
 
 		# encrypt zip.
 		response = self.encrypt_file(input=zip.file_path.path, output=zip.file_path.path, remove=False, base64_encoding=True)
-		if response.success and os.path.exists(zip.file_path.path) :
+		if response.success and Files.exists(zip.file_path.path) :
 			if remove and input != output:
 				try: 
 					os.system(f"rm -fr {input}")
-					if os.path.exists(input): raise PermissionError("")
+					if Files.exists(input): raise PermissionError("")
 				except PermissionError: os.system(f"sudo rm -fr {input}")
 			return r3sponse.success(f"Successfully encrypted directory [{input}].")
 		else:
@@ -264,9 +272,11 @@ class AsymmetricAES(object):
 
 		#
 	def decrypt_directory(self, input=None, output=None, remove=False):
-
+		input = Formats.denitialize(input)
+		ouput = Formats.denitialize(ouput)
+		
 		# checks.
-		file_path = Formats.FilePath(input)
+		file_path = FilePath(input)
 		if not file_path.exists():
 			return r3sponse.error(f"Input [{input}] does not exist.")
 		if file_path.directory():
@@ -285,26 +295,26 @@ class AsymmetricAES(object):
 		# check output.
 		l_dir_path = dir_path
 		if l_dir_path[len(l_dir_path)-1] == "/": l_dir_path = l_dir_path[:-1]
-		if os.path.exists(l_dir_path):
+		if Files.exists(l_dir_path):
 			return r3sponse.error(f"Output path [{l_dir_path}] already exists.")
 		
 		# decrypt zip.
-		tmp_zip = f"/tmp/{Formats.FilePath(input).name()}"
-		if os.path.exists(tmp_zip): os.system(f"rm -fr {tmp_zip}")
+		tmp_zip = f"/tmp/{FilePath(input).name()}"
+		if Files.exists(tmp_zip): os.system(f"rm -fr {tmp_zip}")
 		response = self.decrypt_file(input=input, output=tmp_zip, remove=False, base64_encoding=True)
 		if not response.success:
 			return r3sponse.error(f"Failed to decrypted directory [{input}], error: {response.error}")
 
 		# extract zip.
-		tmp_extract = f"/tmp/{Formats.String('').generate(length=32,capitalize=True,digits=True)}/"
-		if os.path.exists(tmp_extract): os.system(f"rm -fr {tmp_extract}")
+		tmp_extract = f"/tmp/{String('').generate(length=32,capitalize=True,digits=True)}/"
+		if Files.exists(tmp_extract): os.system(f"rm -fr {tmp_extract}")
 		os.mkdir(tmp_extract)
-		zip = Files.Zip(path=tmp_zip)
+		zip = Zip(path=tmp_zip)
 		zip.extract(base=tmp_extract)
 		paths = Files.Directory(path=tmp_extract).paths()
 		if len(paths) == 1:
 			os.system(f"mv {paths[0]} {output}")
-			if os.path.exists(output):
+			if Files.exists(output):
 				os.system(f"rm -fr {tmp_extract}")
 				os.system(f"rm -fr {tmp_zip}")
 				if remove and input != output:
@@ -340,7 +350,7 @@ class Database(object):
 		# arguments.
 		self.aes = aes
 		self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}/"
-		if not os.path.exists(self.path[:-1]): 
+		if not Files.exists(self.path[:-1]): 
 			os.mkdir(self.path)
 			os.system(f"chown {OWNER}:{GROUP} {self.path} && chmod 770 {self.path}")
 
@@ -351,7 +361,7 @@ class Database(object):
 	def activate(self):
 
 		# check sample.
-		if not os.path.exists(f"{self.path}.passphrase"):
+		if not Files.exists(f"{self.path}.passphrase"):
 			response = self.aes.encrypt(self.aes.rsa.passphrase)
 			if not response.success: return response
 			try: utils.__save_bytes__(f"{self.path}.passphrase", response.encrypted)
@@ -427,7 +437,7 @@ class Database(object):
 		):
 			self.path = f"{utils.__clean_url__(path, strip_first=False, strip_last=True, remove_double_slash=True)}"
 			self.aes = aes
-			self.base = Formats.FilePath(path).base()
+			self.base = FilePath(path).base()
 			self.content = None
 			self.format = None
 			self.loaded = False
@@ -440,9 +450,9 @@ class Database(object):
 				"default:dict,list,str,float,int":default,
 				"save:bool":save,})
 			if not response.success: return response
-			if not os.path.exists(self.base): os.system(f"mkdir -p {self.base}")
+			if not Files.exists(self.base): os.system(f"mkdir -p {self.base}")
 			do = False
-			if not os.path.exists(self.path): 
+			if not Files.exists(self.path): 
 				do = True
 				new = default
 			else:
@@ -454,7 +464,7 @@ class Database(object):
 					return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
 					old = dict(self.content)
-					new = Files.Dictionary(path=False, dictionary=old).check(default=default, save=False)
+					new = Dictionary(path=False, dictionary=old).check(default=default, save=False)
 					if dict(new) != dict(old): do = True
 				elif new_format == "list":
 					old = list(self.content)
@@ -478,7 +488,7 @@ class Database(object):
 		# load & decrypt.
 		def load(self):
 			try:
-				content = utils.__load_file__(self.path)
+				content = Files.load(self.path)
 			except Exception as e: return r3sponse.error(f"Failed to load content {self.path}, {e}.")
 			format, content = content.split(" ")
 			response = self.aes.decrypt(content.encode())
